// @ts-check
import { defineConfig, envField } from "astro/config"
import paraglide from "@inlang/paraglide-astro"
import tailwindcss from "@tailwindcss/vite"
import sitemap from "@astrojs/sitemap"
import svelte from "@astrojs/svelte"
import node from "@astrojs/node"
import mdx from "@astrojs/mdx"
import icon from "astro-icon"

import { loadEnv } from "vite"

const { url } = process.env.URL
  ? loadEnv(process.env.URL, process.cwd(), "")
  : { url: "http://localhost:3000" }

// https://astro.build/config
export default defineConfig({
  site: url,
  output: "server",
  i18n: {
    defaultLocale: "nb",
    locales: ["nb", "en"],
  },
  integrations: [
    sitemap(),
    mdx(),
    svelte(),
    icon(),
    paraglide({
      project: "./project.inlang",
      outdir: "./src/paraglide",
    }),
  ],
  adapter: node({
    mode: "standalone",
  }),
  vite: {
    plugins: [tailwindcss()],
  },
  env: {
    schema: {
      DOMAIN: envField.string({ context: "client", access: "public" }),
      URL: envField.string({ context: "client", access: "public" }),
      GIT_URL: envField.string({ context: "client", access: "public" }),
      STATUS_URL: envField.string({ context: "client", access: "public" }),
    },
  },
})
